==> igniteui-react-core-16.16.1.tgz: package/esm2015/lib/SplineSeriesBaseDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeriesDescription } from "./HorizontalAnchoredCategorySeriesDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let SplineSeriesBaseDescription = /*@__PURE__*/ (() => {
    class SplineSeriesBaseDescription extends HorizontalAnchoredCategorySeriesDescription {
        constructor() {
            super();
            this.ep = false;
            this.er = null;
        }
        get_type() {
            return "SplineSeriesBase";
        }
        get isSplineShapePartOfRange() {
            return this.ep;
        }
        set isSplineShapePartOfRange(a) {
            this.ep = a;
            this.e("IsSplineShapePartOfRange");
        }
        get splineType() {
            return this.er;
        }
        set splineType(a) {
            this.er = a;
            this.e("SplineType");
        }
    }
    SplineSeriesBaseDescription.$t = /*@__PURE__*/ markType(SplineSeriesBaseDescription, 'SplineSeriesBaseDescription', HorizontalAnchoredCategorySeriesDescription.$);
    return SplineSeriesBaseDescription;
})();

==> igniteui-react-core-19.0.0.tgz: package/esm2015/lib/SplineSeriesBaseDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeriesDescription } from "./HorizontalAnchoredCategorySeriesDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let SplineSeriesBaseDescription = /*@__PURE__*/ (() => {
    class SplineSeriesBaseDescription extends HorizontalAnchoredCategorySeriesDescription {
        get_type() {
            return "SplineSeriesBase";
        }
        constructor() {
            super();
            this.g1 = false;
            this.g3 = null;
        }
        get isSplineShapePartOfRange() {
            return this.g1;
        }
        set isSplineShapePartOfRange(a) {
            this.g1 = a;
            this.g("IsSplineShapePartOfRange");
        }
        get splineType() {
            return this.g3;
        }
        set splineType(a) {
            this.g3 = a;
            this.g("SplineType");
        }
    }
    SplineSeriesBaseDescription.$t = /*@__PURE__*/ markType(SplineSeriesBaseDescription, 'SplineSeriesBaseDescription', HorizontalAnchoredCategorySeriesDescription.$);
    return SplineSeriesBaseDescription;
})();
